@@ -32,6 +32,12 @@ from xml2rfc.util.unicode import ( punctuation, unicode_replacements, unicode_co
     bare_latin_tags, unicode_attributes, downcode, downcode_punctuation)
 from xml2rfc.utils import namespaces, find_duplicate_ids, slugify
 
+
+DEADLY_ERRORS = [
+    'Element svg has extra content: script',
+    'Did not expect element script there',
+]
+
 default_silenced_messages = [
 #    ".*[Pp]ostal address",
 ]
@@ -49,7 +55,7 @@ default_options.__dict__ = {
         'css': None,
         'config_file': None,
         'country_help': False,
-        'date': datetime.date.today(),
+        'date': None,
         'datestring': None,
         'debug': False,
         'docfile': False,
@@ -436,11 +442,11 @@ class BaseRfcWriter:
 
     # -------------------------------------------------------------------------
 
-    def __init__(self, xmlrfc, quiet=None, options=default_options, date=datetime.date.today()):
+    def __init__(self, xmlrfc, quiet=None, options=default_options, date=None):
         if not quiet is None:
             options.quiet = quiet
         self.options = options
-        self.date = date
+        self.date = date if date is not None else datetime.date.today()
         self.expire_string = ''
         self.ascii = False
         self.nbws_cond = u'\u00A0'
@@ -1711,13 +1717,13 @@ xref_tags   = get_xref_tags()
 
 class BaseV3Writer(object):
 
-    def __init__(self, xmlrfc, quiet=None, options=default_options, date=datetime.date.today()):
+    def __init__(self, xmlrfc, quiet=None, options=default_options, date=None):
         global v3_rnc_file, v3_rng_file, v3_schema
         self.xmlrfc = xmlrfc
         self.tree = xmlrfc.tree if xmlrfc else None
         self.root = self.tree.getroot() if xmlrfc else None
         self.options = options
-        self.date = date
+        self.date = date if date is not None else datetime.date.today()
         self.v3_rnc_file = v3_rnc_file
         self.v3_rng_file = v3_rng_file
         self.v3_rng = lxml.etree.RelaxNG(file=self.v3_rng_file)
@@ -2136,6 +2142,15 @@ class BaseV3Writer(object):
         indent(e, 0)
         e.tail = None
 
+    def deadly_error(self, error):
+        # errors that xml2rfc must not allow to continue
+
+        if error.message in DEADLY_ERRORS:
+            if self.options.verbose:
+                msg = "%s(%s): Error: Can not continue further with error: %s" % (self.xmlrfc.source, error.line, error.message)
+                self.log(msg)
+            return True
+
     def validate(self, when='', warn=False):
         # Note: Our schema doesn't permit xi:include elements, so the document
         # must have had XInclude processing done before calling validate()
@@ -2164,11 +2179,14 @@ class BaseV3Writer(object):
                           "higher for better error messages." % ('.'.join(str(v) for v in lxmlver), ))
             # These warnings are occasionally incorrect -- disable this
             # output for now:
+            deadly = False
             if hasattr(e, 'error_log'):
                 for error in e.error_log:
                     path = getattr(error, 'path', '')
                     msg = "%s(%s): %s: %s, at %s" % (self.xmlrfc.source, error.line, error.level_name.title(), error.message, path)
                     self.log(msg)
+                    if not deadly:
+                        deadly = self.deadly_error(error)
                     if error.message.startswith("Did not expect text"):
                         items = self.tree.xpath(error.path + '/text()')
                         for item in items:
@@ -2179,7 +2197,7 @@ class BaseV3Writer(object):
 
             else:
                 log.warn('\nInvalid document: %s' % (e,))
-            if warn:
+            if warn and not deadly:
                 self.warn(self.root, 'Invalid document%s.' % (when, ))
                 return False
             else:
